==> haskell-ieee754-0.8.0-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ieee754.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ieee754
version: 0.8.0
id: ieee754-0.8.0-B9FdsnFZjDO5G55ttUSqU0
key: ieee754-0.8.0-B9FdsnFZjDO5G55ttUSqU0
license: BSD3
copyright: (c) 2011-2016. Patrick Perry <patperry@gmail.com>
maintainer: Patrick Perry <patperry@gmail.com>
homepage: http://github.com/patperry/hs-ieee754
synopsis: Utilities for dealing with IEEE floating point numbers
description:
    Utilities for dealing with IEEE floating point numbers, ported
    from the Tango math library; approximate and exact equality
    comparisons for general types.
category: Math
author: Patrick Perry
exposed: True
indefinite: False
exposed-modules:
    Data.AEq Numeric.IEEE
abi: 5db827c2e22c3ea000430898b476e941
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/ieee754-0.8.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/ieee754-0.8.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/ieee754-0.8.0
hs-libraries: HSieee754-0.8.0-B9FdsnFZjDO5G55ttUSqU0
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
haddock-interfaces: /usr/share/doc/haskell-ieee754/html/ieee754.haddock
haddock-html: /usr/share/doc/haskell-ieee754/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ieee754-0.8.0-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ieee754.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ieee754
version: 0.8.0
id: ieee754-0.8.0-KmEF4YGiqmIDu40b1SLx46
key: ieee754-0.8.0-KmEF4YGiqmIDu40b1SLx46
license: BSD-3-Clause
copyright: (c) 2011-2016. Patrick Perry <patperry@gmail.com>
maintainer: Patrick Perry <patperry@gmail.com>
author: Patrick Perry
homepage: http://github.com/patperry/hs-ieee754
synopsis: Utilities for dealing with IEEE floating point numbers
description:
    Utilities for dealing with IEEE floating point numbers, ported
    from the Tango math library; approximate and exact equality
    comparisons for general types.
category: Math
abi: 98210f859dac7c4b08e8836715fc2cef
exposed: True
exposed-modules:
    Data.AEq Numeric.IEEE
import-dirs: /usr/lib/ghc-8.4.2/site-local/ieee754-0.8.0
library-dirs: /usr/lib/ghc-8.4.2/site-local/ieee754-0.8.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/ieee754-0.8.0
hs-libraries: HSieee754-0.8.0-KmEF4YGiqmIDu40b1SLx46
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
haddock-interfaces: /usr/share/doc/haskell-ieee754/html/ieee754.haddock
haddock-html: /usr/share/doc/haskell-ieee754/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
